Compute alarm threshold of EO-CUSUM control charts using simulation.
eocusum_arl_h_sim(L0, k, df, coeff, m = 100, yemp = TRUE,
side = "low", nc = 1, jmax = 4, verbose = FALSE)Double. Prespecified in-control Average Run Length.
Double. Reference value of the CUSUM control chart. Either 0 or a positive
value. Can be determined with function optimal_k.
Data Frame. First column are Parsonnet Score values within a range of 0 to
100 representing the preoperative patient risk. The second column are binary (0/1)
outcome values of each operation.
Numeric Vector. Estimated coefficients \(\alpha\) and \(\beta\) from the binary logistic regression model. For more information see details.
Integer. Number of simulation runs.
Logical. If TRUE use observed outcome value, if FALSE use estimated
binary logistc regression model.
Character. Default is "low" to calculate ARL for the upper arm of the V-mask.
If side = "up", calculate the lower arm of the V-mask.
Integer. Number of cores.
Integer. Number of digits for grid search.
Logical. If TRUE verbose output is included, if FALSE a quiet
calculation of h is done.
Returns a single value which is the control limit h for a given ARL.
The function eocusum_arl_h_sim determines the control limit for given in-control
ARL (L0) by applying a multi-stage search procedure which includes secant rule and the
parallel version of eocusum_arl_sim using mclapply.
# NOT RUN {
# This function is deprecated. See eocusum_crit_sim() instead.
# }
Run the code above in your browser using DataLab