Compute steady-state ARLs of risk-adjusted cumulative sum control charts using simulation.
racusum_ad_sim(r, pmix, h, RA = 2, RQ = 1, m = 50, type = "cond")Integer Vector. Number of runs.
Data Frame. A three column data frame. First column is the operation outcome. Second column are the predicted probabilities from the risk model. Third column can be either the predicted probabilities from the risk model or average outcome.
Double. Control Chart limit for detecting deterioration/improvement.
Double. Odds ratio of death under the alternative hypotheses. Detecting deterioration
in performance with increased mortality risk by doubling the odds Ratio RA = 2. Detecting
improvement in performance with decreased mortality risk by halving the odds ratio of death
RA = 1/2. Odds ratio of death under the null hypotheses is 1.
Double. Defines the true performance of a surgeon with the odds ratio ratio of death
RQ. Use RQ = 1 to compute the in-control ARL and other values to compute the
out-of-control ARL.
Integer. Simulated in-control observations.
Character. Default argument is "cond" for computation of conditional
steady-state. Other option is the cyclical steady-state "cycl".
Returns a single value which is the Run Length.