Double. Prespecified in-control Average Run Length.
shape1
Double. Shape parameter \(\alpha\) > 0 of the beta distribution.
shape2
Double. Shape parameter \(\beta\) > 0 of the beta distribution.
coeff
Numeric Vector. Estimated intercept and slope coefficients
from a binary logistic regression model.
rs
Integer. Number of intervals between 0 and the maximum risk score.
RA
Double. Odds ratio of death under the alternative hypotheses. Detecting deterioration
in performance with increased mortality risk by doubling the odds Ratio RA = 2. Detecting
improvement in performance with decreased mortality risk by halving the odds ratio of death
RA = 1/2.
RQ
Double. Defines the performance of a surgeon with the odds ratio ratio of death.
Q.
nc
Integer. Number of cores used for parallel processing. Value is passed to
parSapply.
hmax
Integer. Maximum value of h for the grid search.
jmax
Integer. Number of digits for grid search.
m
Integer. Number of simulation runs.
verbose
Logical. If TRUE verbose output is included, if FALSE a quiet
calculation of h is done.
Value
Returns a single value which is the control limit h for a given in-control ARL.